DeLU (Deep Learning Utilities)
==============================

:bdg-secondary:`v0.0.24.dev0`
:bdg-link-secondary-line:`Other versions <https://yura52.github.io/delu/versions.html>`
:bdg-link-secondary-line:`Source code <https://github.com/Yura52/delu>`

.. include:: ../README.rst
   :start-after: __INCLUDE_0__

.. toctree::
   :caption: API
   :hidden:

   api/delu
   api/delu.cuda
   api/delu.nn
   api/delu.random
   api/delu.tools

.. toctree::
   :caption: Other
   :hidden:

   api/deprecated

----

Indices and Tables
------------------

* :ref:`genindex`
* :ref:`modindex`
